@@ -1,7 +1,7 @@
 package parent;
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.231';
+$VERSION = '0.233';
 
 sub import {
     my $class = shift;
@@ -12,10 +12,6 @@ sub import {
         shift @_;
     } else {
         for ( my @filename = @_ ) {
-            if ( $_ eq $inheritor ) {
-                warn "Class '$inheritor' tried to inherit from itself\n";
-            };
-
             s{::|'}{/}g;
             require "$_.pm"; # dies if the file is not found
         }
@@ -94,19 +90,6 @@ either C<.pm> or C<.pmc>), use the following code:
   require './plugins/custom.plugin'; # contains Plugin::Custom
   use parent -norequire, 'Plugin::Custom';
 
-=head1 DIAGNOSTICS
-
-=over 4
-
-=item Class 'Foo' tried to inherit from itself
-
-Attempting to inherit from yourself generates a warning.
-
-    package Foo;
-    use parent 'Foo';
-
-=back
-
 =head1 HISTORY
 
 This module was forked from L<base> to remove the cruft
